@@ -20,4 +20,4 @@ pose.add_stream('yarp')
 camera.add_stream('yarp')
 
 env = Environment('indoors-1/indoor-1')
-env.aim_camera([1.0470, 0, 0.7854])
+env.set_camera_rotation([1.0470, 0, 0.7854])
