@@ -9,7 +9,7 @@ bpy = None
 try:
     import bpy
 except ImportError:
-    print("ATTENTION: MORSE is running outside Blender! (no bpy)")
+    print("WARNING: MORSE is running outside Blender! (no bpy)")
 
 def empty_method(*args, **kwargs):
     print(args, kwargs)
@@ -40,6 +40,7 @@ new_object = empty_method
 apply_transform = empty_method
 open_sound = empty_method
 new_scene = empty_method
+armatures = empty_method
 
 if bpy:
     select_all = bpy.ops.object.select_all
@@ -69,6 +70,14 @@ if bpy:
     apply_transform = bpy.ops.object.transform_apply
     open_sound = bpy.ops.sound.open
     new_scene = bpy.ops.scene.new
+    armatures = bpy.data.armatures
+
+def version():
+    if bpy:
+        return bpy.app.version
+    else:
+        return 0,0,0
+
 
 def create_new_material():
     all_materials = get_materials().keys()
@@ -77,10 +86,10 @@ def create_new_material():
                      if name not in all_materials].pop()
     return get_material(material_name)
 
-def add_morse_empty():
+def add_morse_empty(shape = 'ARROWS'):
     """Add MORSE Component Empty object which hlods MORSE logic"""
     if bpy.app.version >= (2, 65, 0):
-        add_empty(type='ARROWS')
+        add_empty(type = shape)
     else:
         add_object(type='EMPTY')
 
@@ -171,6 +180,18 @@ def get_scene(name_or_id):
     else:
         return None
 
+def set_active_scene(name_or_id):
+    if bpy:
+        scene = get_scene(name_or_id)
+        if scene:
+            bpy.data.screens['Default'].scene = scene
+            bpy.context.screen.scene = scene
+            return scene
+        else:
+            return None
+    else:
+        return None
+
 def get_last_scene():
     return get_scene(-1)
 
@@ -344,7 +365,7 @@ def _property_set(obj, name_or_id, value, ptype=None):
     :param ptype: property type (enum in ['BOOL', 'INT', 'FLOAT', 'STRING', 'TIMER'],
                   optional, auto-detect, default=None)
     """
-    if ptype == None:
+    if ptype is None:
         # Detect the type (class name upper case)
         ptype = value.__class__.__name__.upper()
     if ptype == 'STR':
@@ -380,3 +401,13 @@ def set_viewport_perspective(perspective='CAMERA'):
             for space in area.spaces:
                 if space.type == 'VIEW_3D':
                     space.region_3d.view_perspective = 'CAMERA'
+
+def fullscreen(fullscreen=True):
+    """ Run the simulation fullscreen
+
+    :param fullscreen: Start player in a new fullscreen display
+    :type  fullscreen: Boolean, default: True
+    """
+    if not bpy:
+        return
+    bpy.context.scene.game_settings.show_fullscreen = fullscreen
