@@ -2,6 +2,8 @@ import logging; logger = logging.getLogger("morsebuilder." + __name__)
 import os
 import json
 from morse.builder.morsebuilder import *
+from morse.builder.abstractcomponent import Configuration
+from morse.core.morse_time import TimeStrategies
 
 class Environment(Component):
     """ Class to configure the general environment of the simulation
@@ -42,6 +44,7 @@ class Environment(Component):
         self._display_camera = None
         self.is_material_mode_custom = False
         self._node_name = None
+        self._physics_step_sub = 2
         # Add empty object holdings MORSE Environment's properties
         # for UTM modifier configutation ( uses env.properties(...) )
         bpymorse.deselect_all()
@@ -160,25 +163,33 @@ class Environment(Component):
 
 
     def place_camera(self, location):
+        logger.warning("`place_camera` is deprecated, use `set_camera_location` instead")
+        self.set_camera_location(location)
+
+    def aim_camera(self, rotation):
+        logger.warning("`aim_camera` is deprecated, use `set_camera_rocation` instead")
+        self.set_camera_rotation(rotation)
+
+    def set_camera_location(self, location):
         """ Set the location of the default camera.
 
         :param location: list with the new 3D coordinates for the camera.
 
         .. code-block:: python
 
-            env.place_camera([10.0, -10.0, 3.0])
+            env.set_camera_location([10.0, -10.0, 3.0])
 
         """
         self._camera_location = location
 
-    def aim_camera(self, rotation):
+    def set_camera_rotation(self, rotation):
         """ Set the orientation of the default camera
 
         :param rotation: list with an euler rotation for the camera.
 
         .. code-block:: python
 
-            env.aim_camera([1.3300, 0, 0.7854])
+            env.set_camera_rotation([1.3300, 0, 0.7854])
 
         """
         self._camera_rotation = rotation
@@ -201,30 +212,26 @@ class Environment(Component):
 
     def _cfg_camera_scene(self):
         scene = bpymorse.get_context_scene()
-        scene.name = 'S.MORSE_ENV'
-        scene.game_settings.physics_engine = 'NONE'
+        scene.name = 'S.MORSE_LOGIC'
         from morse.builder.sensors import VideoCamera
-        cfg_camera_scene = {}
+        cfg_camera_scene = []
         for component in AbstractComponent.components:
             # do not create scene for external camera
             if isinstance(component, VideoCamera) and \
                     self.is_internal_camera(component):
-                # Create a new scene for the Camera
-                bpymorse.new_scene(type='LINK_OBJECTS')
-                scene = bpymorse.get_context_scene()
-                scene.name = 'S.%s'%component.name
-                scene.render.resolution_x = component.property_value('cam_width')
-                scene.render.resolution_y = component.property_value('cam_height')
-                # TODO disable logic and physic in this created scene
-                cfg_camera_scene[component.name] = scene.name
-
-        # Create 'camera_scene.py' configuration file (like 'component_config.py')
-        # mapping Camera -> Scene for the bge.texture.ImageRender(scene, camera)
-        bpymorse.new_text()
-        bpymorse.get_last_text().name = 'camera_scene.py'
-        cfg = bpymorse.get_text('camera_scene.py')
-        cfg.write('camera_scene = ' + json.dumps(cfg_camera_scene, indent=1) )
-        cfg.write('\n')
+                res_x = component.property_value('cam_width')
+                res_y = component.property_value('cam_height')
+                name = 'S.%dx%d' % (res_x, res_y)
+                if not name in cfg_camera_scene:
+                    # Create a new scene for the Camera
+                    bpymorse.new_scene(type='LINK_OBJECTS')
+                    scene = bpymorse.get_context_scene()
+                    scene.name = name
+                    scene.render.resolution_x = res_x
+                    scene.render.resolution_y = res_y
+                    scene.game_settings.physics_engine = 'NONE'
+                    # TODO disable logic and physic in this created scene
+                    cfg_camera_scene.append(name)
 
     def create(self, name=None):
         """ Generate the scene configuration and insert necessary objects
@@ -238,7 +245,7 @@ class Environment(Component):
                 component.after_renaming()
 
         # Compute node name
-        if name == None:
+        if name is None:
             try:
                 self._node_name = os.environ["MORSE_NODE"]
             except KeyError:
@@ -252,10 +259,9 @@ class Environment(Component):
         self._cfg_camera_scene()
 
         # Create a new scene for the MORSE_LOGIC (Scene_Script_Holder, CameraFP)
-        bpymorse.new_scene(type='LINK_OBJECTS')
-        scene = bpymorse.get_context_scene()
-        scene.name = 'S.MORSE_LOGIC'
+        scene = bpymorse.set_active_scene('S.MORSE_LOGIC')
         scene.game_settings.physics_engine = 'BULLET'
+        scene.game_settings.physics_step_sub = self._physics_step_sub
         # set simulation view resolution (4:3)
         scene.render.resolution_x = 800
         scene.render.resolution_y = 600
@@ -282,6 +288,10 @@ class Environment(Component):
         # Write the name of the 'environment file'
         self.properties(environment_file = str(self._environment_file))
 
+        # Default time management
+        if 'time_management' not in self._bpy_object.game.properties.keys():
+            self.properties(time_management = TimeStrategies.BestEffort)
+
         if self.fastmode:
             # SINGLETEXTURE support has been removed between 2.69 and
             # 2.70. Handle properly the case where it is not defined
@@ -322,7 +332,12 @@ class Environment(Component):
         # Set viewport to Camera
         bpymorse.set_viewport_perspective()
 
+        hud_text = bpymorse.get_object('Keys_text')
+        hud_text.scale.y = 0.027 # to fit the HUD_plane
+
         self._created = True
+        # in case we are in edit mode, do not exit on error with CLI
+        sys.excepthook = sys_excepthook # Standard Python excepthook
 
     def set_horizon_color(self, color=(0.05, 0.22, 0.4)):
         """ Set the horizon color
@@ -392,8 +407,35 @@ class Environment(Component):
         bpymorse.get_context_scene().render.engine = 'BLENDER_GAME'
         bpymorse.get_context_scene().game_settings.use_auto_start = auto_start
 
+    def set_time_strategy(self, strategy):
+        """ Choose the time strategy for the current simulation
+
+        :param strategy:  the strategy to choose. Must be one of value
+        of :py:class:`morse.builder.TimeStrategies`
+        """
+        if strategy == TimeStrategies.FixedSimulationStep:
+            bpymorse.get_context_scene().game_settings.use_frame_rate = 0
+        elif strategy == TimeStrategies.BestEffort:
+            bpymorse.get_context_scene().game_settings.use_frame_rate = 1
+        else:
+            raise ValueError(strategy)
+
+        self.properties(time_management = strategy)
+
+    def fullscreen(self, fullscreen=True):
+        """ Run the simulation fullscreen
+
+        :param fullscreen: Start player in a new fullscreen display
+        :type  fullscreen: Boolean, default: True
+        """
+        bpymorse.fullscreen(fullscreen)
+
     def set_debug(self, debug=True):
-        """ Set the debug bit in blender """
+        """ Set Blender debug mode
+
+        :param debug: set when blender is running in debug mode (started with --debug)
+        :type  debug: Boolean, default: True
+        """
         bpymorse.set_debug(debug)
 
     def set_stereo(self, mode='ANAGLYPH', eye_separation=0.1, stereo='STEREO'):
@@ -422,6 +464,18 @@ class Environment(Component):
         """
         bpymorse.get_context_scene().game_settings.use_animation_record = record
 
+    def set_physics_step_sub(self, step_sub):
+        """ Configure the number of physics sub step per physics step.
+
+        Basically, if you increase the step_sub value, your simulation
+        will spent more time in computing physics, but it will be more
+        precise. The default value is 2.
+
+        See also
+        http://www.blender.org/documentation/blender_python_api_2_63_0/bpy.types.SceneGameData.html#bpy.types.SceneGameData.physics_step_sub
+        """
+        self._physics_step_sub = step_sub
+
     def configure_multinode(self, protocol='socket',
             server_address='localhost', server_port='65000', distribution=None):
         """ Provide the information necessary for the node to connect to a multi-node server.
@@ -452,7 +506,7 @@ class Environment(Component):
         self._protocol = protocol
         self._server_address = server_address
         self._server_port = server_port
-        if distribution != None:
+        if distribution is not None:
             self.multinode_distribution = distribution
         self._multinode_configured = True
 
