@@ -1,7 +1,10 @@
 import logging; logger = logging.getLogger("morsebuilder." + __name__)
 import sys
 import math
-from morse.builder.abstractcomponent import *
+from morse.builder.blenderobjects import Cube
+from morse.builder import bpymorse
+from morse.builder.abstractcomponent import AbstractComponent
+from morse.core.exceptions import *
 
 """
 Morse Builder API
@@ -27,6 +30,7 @@ def morse_excepthook(*args, **kwargs):
     sys_excepthook(*args, **kwargs)
     import os
     os._exit(-1)
+
 # Uncaught exception quit Blender
 sys.excepthook = morse_excepthook
 
@@ -52,7 +56,7 @@ class PassiveObject(AbstractComponent):
         """
         AbstractComponent.__init__(self, filename=filename)
 
-        logger.info("Importing the following passive object(s): %s" % (prefix))
+        logger.info("Importing the following passive object(s): %s" % prefix)
 
         imported_objects = self.append_meshes(prefix=prefix)
         # Here we use the fact that after appending, Blender select the objects
@@ -90,6 +94,24 @@ class PassiveObject(AbstractComponent):
             contr = obj.game.controllers[-1]
             contr.link(sensor = sens)
 
+class Zone(Cube):
+    def __init__(self, type):
+        Cube.__init__(self, 'xxx')
+        # Need to create a new material before calling make_transparent
+        self._bpy_object.active_material = bpymorse.create_new_material()
+        self._make_transparent(self._bpy_object, 1e-6)
+        self.properties(Zone_Tag = True, Type = type)
+
+    @property
+    def size(self):
+        return self._bpy_object.scale
+    @size.setter
+    def size(self, value):
+        self._bpy_object.scale = value
+
+    def rotate(self, x=0.0, y=0.0, z=0.0):
+        logger.warning("rotate is not supported for Zone")
+
 class Component(AbstractComponent):
     """ Append a morse-component to the scene
 
@@ -117,23 +139,8 @@ class Component(AbstractComponent):
             self.morseable()
 
 
-class Armature(AbstractComponent):
-    def __init__(self, objectname, filename='armature'):
-        """ Initialize an Armature
-
-        :param objectname: Armature name
-        :param filename: for datastream configuration, default 'armature'
-        """
-        AbstractComponent.__init__(self, filename=filename, category='actuators')
-        self.set_blender_object(bpymorse.get_object(objectname))
-        # default classpath for Armature (can be modified)
-        if not self.is_morseable():
-            self.morseable()
-        self.properties(classpath="morse.actuators.armature.Armature")
-
-
 class Robot(Component):
-    def __init__(self, filename, name):
+    def __init__(self, filename = '', name = None):
         Component.__init__(self, 'robots', filename)
         self.properties(Robot_Tag = True)
         self.default_interface = None
@@ -187,7 +194,32 @@ class Robot(Component):
         """
         self._make_transparent(self._bpy_object, alpha)
 
-class WheeledRobot(Robot):
+    def set_rigid_body(self):
+        """ Configure this robot to use rigid_body physics """
+        self._bpy_object.game.use_actor = True
+        self._bpy_object.game.physics_type = 'RIGID_BODY'
+        self._bpy_object.game.use_sleep = True
+
+    def set_no_collision(self):
+        """ Configure this robot to not use physics at all """
+        self._bpy_object.game.physics_type = 'NO_COLLISION'
+
+    def set_dynamic(self):
+        self._bpy_object.game.physics_type = 'DYNAMIC'
+        self._bpy_object.game.use_actor = True
+        self._bpy_object.game.use_sleep = True
+
+    def set_collision_bounds(self):
+        self._bpy_object.game.use_collision_bounds = True
+        self._bpy_object.game.collision_bounds_type = 'CONVEX_HULL'
+        self._bpy_object.game.use_collision_compound = True
+
+class GroundRobot(Robot):
+    def __init__(self, filename, name):
+        Robot.__init__(self, filename, name)
+        self.properties(GroundRobot = True)
+
+class WheeledRobot(GroundRobot):
     def __init__(self, filename, name):
         Robot.__init__(self, filename, name)
 
@@ -196,15 +228,24 @@ class WheeledRobot(Robot):
             the parent robot """
         # Force Blender to update the transformation matrices of objects
         bpymorse.get_context_scene().update()
+
         wheels = [child for child in self._bpy_object.children if \
                   "wheel" in child.name.lower()]
-        # fix #421 - multi WheeledRobot - wheels must be ordered as:
-        # front-right, front-left, rear-right, rear-left
-        wnames = [w.name for w in wheels]
-        wnames.sort()
-        wnames.extend(['None'] * 4) # in case of < 4 wheels
+        wnames = ['None'] * 5
+        keys = ['WheelFLName', 'WheelFRName', 'WheelRLName',
+                'WheelRRName', 'CasterWheelName']
+        properties = bpymorse.get_properties(self._bpy_object)
+        for i in range(5):
+            key = keys[i]
+            expected_wheel = properties.get(key, None)
+            if expected_wheel:
+                for wheel in wheels:
+                    if wheel.name.startswith(expected_wheel):
+                        wnames[i] = wheel.name
+
         self.properties(WheelFLName = wnames[0], WheelFRName = wnames[1],
-                        WheelRLName = wnames[2], WheelRRName = wnames[3])
+                        WheelRLName = wnames[2], WheelRRName = wnames[3],
+                        CasterWheelName = wnames[4])
         for wheel in wheels:
             # Make a copy of the current transformation matrix
             transformation = wheel.matrix_world.copy()
@@ -233,6 +274,101 @@ class Sensor(Component):
         self.properties(Component_Tag = True)
 
 class Actuator(Component):
-    def __init__(self, filename):
+    def __init__(self, filename = None):
         Component.__init__(self, 'actuators', filename)
         self.properties(Component_Tag = True)
+
+
+class Armature(Actuator):
+    def __init__(self, armature_name = None, model_name = None):
+        """ Initialize an Armature
+
+        :param armature_name: Armature object name
+        :param model_name: Armature model name, if any
+        """
+        Actuator.__init__(self, filename = model_name)
+
+        if not armature_name and not model_name:
+            raise MorseBuilderError("You need to specify either the name of " \
+                    "an armature or a Blender model in order to create an " \
+                    "armature actuator.")
+
+        if armature_name:
+            if not model_name:
+                # no model name given -> MORSE automatically added an empty
+                # for this actuator, which we do not want since we provide
+                # our own Blender armature.
+                bpymorse.delete([self._bpy_object])
+            self.set_blender_object(bpymorse.get_object(armature_name))
+            self.properties(Component_Tag = True)
+
+        # default classpath for Armature (can be modified)
+        self.properties(classpath="morse.actuators.armature.Armature")
+
+        self.ik_targets = []
+
+        # the user may have created IK constraints on the armature, without
+        # setting an IK target. In that case, we add such a target
+        for bone in self._bpy_object.pose.bones:
+            for c in bone.constraints:
+                if c.type == 'IK' and c.ik_type == 'DISTANCE':
+                    if not c.target:
+                        self.create_ik_targets([bone.name])
+
+    def _get_posebone(self, bone_name):
+        """ Returns a given PoseBone in the armature.
+
+        If the joint does not exist, throw an exception.
+        """
+        armature = self._bpy_object
+
+        if bone_name not in [c.name for c in armature.pose.bones]:
+            msg = "Joint <%s> does not exist in model %s." % (bone_name, armature.name)
+            msg += " Did you add a skeleton to your model in MakeHuman?"
+            raise MorseBuilderError(msg)
+
+        return armature.pose.bones[bone_name]
+
+    def create_ik_targets(self, bones):
+
+        # Bug with iTaSC! cf http://developer.blender.org/T37894
+        if bpymorse.version() < (2, 70, 0):
+            if self._bpy_object.pose.ik_solver == 'ITASC':
+                logger.warn("Due to a bug in Blender (T37894), only the standard " \
+                            "IK solver can be used with IK targets. Switching " \
+                            "from iTaSC to standard IK solver.")
+                self._bpy_object.pose.ik_solver = 'LEGACY'
+
+        for target in bones:
+            posebone = self._get_posebone(target)
+            bpymorse.add_morse_empty("ARROWS")
+            empty = bpymorse.get_first_selected_object()
+            empty.scale = [0.01, 0.01, 0.01]
+
+            empty.matrix_local = posebone.bone.matrix_local
+            empty.location = posebone.bone.tail_local
+
+            existing_ik = [c for c in posebone.constraints if c.type == 'IK']
+            if len(existing_ik) == 1:
+                ik_constraint = existing_ik[0]
+            elif existing_ik:
+                raise MorseBuilderError("Bone %s has several IK constraints." \
+                        "MORSE supports only one IK constraint per bone. Please " \
+                        "remove other ones.")
+            else:
+                ik_constraint = posebone.constraints.new("IK")
+
+            ik_constraint.ik_type = "DISTANCE"
+            ik_constraint.use_rotation = True
+            ik_constraint.use_tail = True
+            ik_constraint.target = empty
+
+            self.ik_targets.append((empty, target))
+
+
+    def after_renaming(self):
+        for empty, target in self.ik_targets:
+            empty.name = "ik_target." + self.name + "." + target
+
+
+
