@@ -1,8 +1,9 @@
 import logging; logger = logging.getLogger("morserobots." + __name__)
 from morse.builder import bpymorse
-from morse.builder import Armature, Robot
+from morse.builder import Armature, GroundRobot
+from morse.builder.sensors import ArmaturePose
 
-class Human(Robot):
+class Human(GroundRobot):
     """ Append a human model to the scene.
 
     The human model currently available in MORSE comes with its
@@ -32,7 +33,7 @@ class Human(Robot):
 
         :param filename: 'human' (default) or 'mocap_human'
         """
-        Robot.__init__(self, filename, name)
+        GroundRobot.__init__(self, filename, name)
 
         self.suffix = self.name[-4:] if self.name[-4] == "." else ""
 
@@ -43,9 +44,7 @@ class Human(Robot):
             self.properties(classpath="morse.robots.human.Human")
 
         try:
-            self.armature = Armature("HumanArmature" + self.suffix, "human_posture")
-            # new way of loading class (drop 'Class' and 'Path' properties)
-            self.armature.properties(classpath="morse.sensors.human_posture.HumanPosture")
+            self.armature = Armature("HumanArmature" + self.suffix)
             self.append(self.armature)
         except KeyError:
             logger.error("Could not find the human armature! (I was looking " +\
@@ -53,6 +52,10 @@ class Human(Robot):
                          " children). I won't be able to export the human pose" +\
                          " to any middleware.")
 
+        # Add an armature sensor. "joint_stateS" to match standard ROS spelling.
+        self.joint_states = ArmaturePose()
+        self.armature.append(self.joint_states)
+
         # fix for Blender 2.6 Animations
         armature_object = self.get_child(self.armature.name)
         if armature_object:
@@ -91,6 +94,22 @@ class Human(Robot):
         prop[-1].type = "STRING"
         prop[-1].value = self.name
 
+    def add_interface(self, interface):
+        if interface == "socket":
+            self.joint_states.add_stream("socket")
+            self.armature.add_service('socket')
+
+        elif interface == "ros":
+
+            self.joint_states.add_stream("ros")
+
+            self.armature.add_service("ros")
+            self.armature.add_overlay("ros",
+              "morse.middleware.ros.overlays.armatures.ArmatureController")
+
+        elif interface == "pocolibs":
+            self.armature.properties(classpath="morse.sensors.human_posture.HumanPosture")
+            self.add_stream(interface)
 
 
     def use_world_camera(self):
