@@ -49,6 +49,10 @@ class PhysicsWheelRobot(morse.core.robot.Robot):
         # bullet vehicles always have 4 wheels
         scene = blenderapi.scene()
 
+        self._wheel_radius = None
+
+        caster_wheel_name = self.bge_object.get('CasterWheelName', None)
+
         #  inherited from the parent robot
         for index in self._wheel_index:
             name = "Wheel%sName" % index
@@ -58,7 +62,7 @@ class PhysicsWheelRobot(morse.core.robot.Robot):
                 wheel = scene.objects[self.bge_object[name]]
             except:
                 #import traceback
-                #traceback.print_exc()
+                #traceback._exc()
                 wheel = None
 
             if wheel:
@@ -74,15 +78,15 @@ class PhysicsWheelRobot(morse.core.robot.Robot):
                 #wheel.worldPosition = self._wheel_positions[index]
                 #wheel.worldOrientation = self._wheel_orientations[index]
 
+                # get wheel radius if not already computed
+                if wheel.name != caster_wheel_name and not self._wheel_radius:
+                    self._wheel_radius = self.get_wheel_radius(self.bge_object[name])
+
         logger.debug("get_wheels %s" % self._wheels)
 
-        # get wheel radius
-        self._wheel_radius = \
-            self.get_wheel_radius(self.bge_object['WheelFLName'])
-
         # Add a free rotating wheel if indicated in the robot
-        if 'CasterWheelName' in self.bge_object:
-            wheel = scene.objects[self.bge_object['CasterWheelName']]
+        if caster_wheel_name and caster_wheel_name != 'None':
+            wheel = scene.objects[caster_wheel_name]
             wheel_position = mathutils.Vector(wheel.worldPosition)
             self.attach_caster_wheel_to_body(wheel, self.bge_object, wheel_position)
 
@@ -99,7 +103,8 @@ class PhysicsWheelRobot(morse.core.robot.Robot):
     def get_wheel_radius(self, wheel_name):
         dims = blenderapi.objectdata(wheel_name).dimensions
         # average the x and y dimension to get diameter - divide by 2 for radius
-        return (dims[0]+dims[1])/4
+        radius = (dims[0]+dims[1])/4
+        return radius
 
 
 class MorsePhysicsRobot(PhysicsWheelRobot):
@@ -108,10 +113,18 @@ class MorsePhysicsRobot(PhysicsWheelRobot):
     Inherits from the base robot class.
     """
 
+    add_property('_fix_turning', 0.0, 'FixTurningSpeed', 'double', 
+                'Overwrite the value of the distance between wheels in '
+                'the computations of the wheel speeds. This effectively '
+                'changes the turning speed of the robot, and can be used '
+                'to compensate for the slip of the wheels while turning. '
+                'If the value 0.0 is used, the real distance between wheels '
+                'is used.')
+
     def __init__ (self, obj, parent=None):
         """ Constructor method. """
         # Call the constructor of the parent class
-        super(MorsePhysicsRobot, self).__init__(obj, parent)
+        PhysicsWheelRobot.__init__(self, obj, parent)
 
         # get wheel references and ID's
         self.get_wheels()
@@ -119,6 +132,14 @@ class MorsePhysicsRobot(PhysicsWheelRobot):
         # construct the vehicle
         self.build_vehicle()
 
+        if self._fix_turning != 0.0:
+            self._trackWidth = self._fix_turning
+
+        logger.warn("Using wheel separation of %.4f" % self._trackWidth)
+
+        # Force speed at 0.0 at startup
+        self.apply_vw_wheels(0.0, 0.0)
+
 
     def build_vehicle(self):
         """ Apply the constraints to the vehicle parts. """
@@ -127,7 +148,7 @@ class MorsePhysicsRobot(PhysicsWheelRobot):
         self._chassis_ID = self.bge_object.getPhysicsId()
 
         # get track width
-        self._trackWidth = self.get_track_width();
+        self._trackWidth = self.get_track_width()
 
         # set up wheel constraints
         # add wheels to either suspension arms or vehicle chassis
@@ -242,6 +263,49 @@ class MorsePhysicsRobot(PhysicsWheelRobot):
         joint.setParam(5, 0.0, 0.0) # no rotation about Z axis - min=0, max=0
         return joint # return a reference to the constraint
 
+    def apply_vw_wheels(self, vx, vw):
+        """ Apply (v, w) to the parent robot. """
+
+        # calculate desired wheel speeds and set them
+        if abs(vx) < 0.001 and abs(vw) < 0.001:
+            # stop the wheel when velocity is below a given threshold
+            for index in self._wheels.keys():
+                self._wheel_joints[index].setParam(9, 0, 100.0)
+
+            self._stopped = True
+        else:
+            # this is need to "wake up" the physic objects if they have
+            # gone to sleep apply a tiny impulse straight down on the
+            # object
+            if self._stopped:
+                self.bge_object.applyImpulse(
+                   self.bge_object.position, (0.0, 0.1, -0.000001))
+
+            # no longer stopped
+            self._stopped = False
+
+            # Another formula for computing left and right wheel speeds:
+            # http://arri.uta.edu/acs/jmireles/Robotics/KinematicsMobileRobots.pdf
+            v_ws_l = vx - (self._trackWidth / 2.0) * vw
+            v_ws_r = vx + (self._trackWidth / 2.0) * vw
+
+            # convert to angular speeds
+            w_ws_l = v_ws_l / self._wheel_radius
+            w_ws_r = v_ws_r / self._wheel_radius
+
+            # set wheel speeds - front and rear wheels have the same speed
+            # Left side wheels
+            self._wheel_joints['FL'].setParam(9, w_ws_l, 100.0)
+            if 'RL' in self._wheels:
+                self._wheel_joints['RL'].setParam(9, w_ws_l, 100.0)
+            # Right side wheels
+            self._wheel_joints['FR'].setParam(9, w_ws_r, 100.0)
+            if 'RR' in self._wheels:
+                self._wheel_joints['RR'].setParam(9, w_ws_r, 100.0)
+
+            logger.debug("New speeds set: left=%.4f, right=%.4f" %
+                         (w_ws_l, w_ws_r))
+
 
     def AttachWheelWithSuspension(self, wheel, parent, suspensionArm):
         """ Attaches the wheel to the a-arm and then the a-arm to the body """
