@@ -1,9 +1,9 @@
 import logging; logger = logging.getLogger("morse." + __name__)
-import roslib; roslib.load_manifest('motion_control_msgs');
+import roslib; roslib.load_manifest('motion_control_msgs')
 from motion_control_msgs.msg import JointPositions
-from morse.middleware.ros import ROSReader
+from morse.middleware.ros import ROSSubscriber
 
-class JointPositionsReader(ROSReader):
+class JointPositionsReader(ROSSubscriber):
 
     ros_class = JointPositions
 
