@@ -1,5 +1,5 @@
 import logging; logger = logging.getLogger("morse." + __name__)
-import roslib; roslib.load_manifest('sensor_msgs');
+import roslib; roslib.load_manifest('sensor_msgs')
 from sensor_msgs.msg import JointState
 from morse.middleware.ros import ROSPublisher
 
