@@ -1,8 +1,8 @@
 import roslib; roslib.load_manifest('geometry_msgs')
 from geometry_msgs.msg import Vector3
-from morse.middleware.ros import ROSReader
+from morse.middleware.ros import ROSSubscriber
 
-class Vector3Reader(ROSReader):
+class Vector3Reader(ROSSubscriber):
     """ Subscribe to a Vector3 topic and set pan,tilt local data, according to
     the rotation axis (pan: y-axis, tilt: z-axis).
     """
