@@ -15,8 +15,8 @@ class SemanticCameraPublisher(ROSPublisherTF):
     def default(self, ci='unused'):
         for obj in self.data['visible_objects']:
             # send tf-frame for every object
-            self.sendTransform(obj['position'], obj['orientation'], \
-                               rospy.Time.now(), str(obj['name']), "/map")
+            self.sendTransform(obj['position'], obj['orientation'],
+                               self.get_time(), str(obj['name']), "/map")
         string = String()
         string.data = json.dumps(self.data['visible_objects'], cls=MorseEncoder)
         self.publish(string)
@@ -37,8 +37,8 @@ class SemanticCameraPublisherLisp(ROSPublisherTF):
             description = obj['description'] or '-'
 
             # send tf-frame for every object
-            self.sendTransform(obj['position'], obj['orientation'], \
-                               rospy.Time.now(), str(obj['name']), "/map")
+            self.sendTransform(obj['position'], obj['orientation'],
+                               self.get_time(), str(obj['name']), "/map")
 
             # Build string from name, description, location and orientation in the global world frame
             string.data += "(" + str(obj['name']) + " " + description + " " + \
