@@ -1,9 +1,9 @@
 import logging; logger = logging.getLogger("morse." + __name__)
 import roslib; roslib.load_manifest('geometry_msgs')
 from geometry_msgs.msg import Pose2D
-from morse.middleware.ros import ROSReader
+from morse.middleware.ros import ROSSubscriber
 
-class Pose2DReader(ROSReader):
+class Pose2DReader(ROSSubscriber):
     """ Subscribe to a Pose2D topic and set ``x``, ``y``, ``z`` local data.
     This is designed to be used with the waypoint actuator.
     """
