@@ -109,7 +109,7 @@ class YarpImagePublisher(YarpPort):
         img_Y = self.component_instance.image_height
 
         # Check that an image exists:
-        if img_string != None and img_string != '':
+        if img_string is not None and img_string != '':
             try:
                 data = img_string
                 # Pass the data as is, from the bge.texture module
@@ -135,7 +135,7 @@ class YarpReader(YarpPort):
     def default(self, ci):
         message_data = self.port.read(False)
 
-        if message_data != None:
+        if message_data is not None:
             # Data elements are of type defined in data_types
             i = 0
             for variable, data in self.data.items():
@@ -155,19 +155,19 @@ class YarpReader(YarpPort):
                     logger.error("Unknown data type at 'read_message', "
                                  "with component '%s'" % self.component_name)
                     logger.info("DATA: ", data, " | TYPE: ", type(data))
-                i = i + 1
+                i += 1
             return True
 
         else:
             return False
 
-class Yarp(Datastream):
+class YarpDatastreamManager(DatastreamManager):
     """ Handle communication between Blender and YARP."""
 
     def __init__(self):
         """ Initialize the network and connect to the yarp server."""
         # Call the constructor of the parent class
-        super(self.__class__,self).__init__()
+        DatastreamManager.__init__(self)
 
         yarp.Network.init()
 
