@@ -10,7 +10,7 @@ class ATRV(morse.core.robot.Robot):
 
     def __init__(self, obj, parent=None):
         logger.info('%s initialization' % obj.name)
-        super(self.__class__, self).__init__(obj, parent)
+        morse.core.robot.Robot.__init__(self, obj, parent)
 
         logger.info('Component initialized')
 
