@@ -15,7 +15,7 @@ class PatrolBot(morse.core.wheeled_robot.MorsePhysicsRobot):
     def __init__(self, obj, parent=None):
         # Call the constructor of the parent class
         logger.info('%s initialization' % obj.name)
-        super(self.__class__, self).__init__(obj, parent)
+        morse.core.wheeled_robot.MorsePhysicsRobot.__init__(self, obj, parent)
 
         logger.info('Component initialized')
 
