@@ -6,13 +6,31 @@ class Quadrotor(morse.core.robot.Robot):
     """
     Definition of a generic **quadrotor** without ``Rigid Body`` physics.
     It is expected to be used with actuators such as:
-     - :doc:`../actuators/stabilized_quadrotor`
+
+    - :doc:`../actuators/stabilized_quadrotor`
+
+    .. example::
+        from morse.builder import *
+
+        quadrotor = QUAD2012()
+
+        # place your component at the correct location
+        quadrotor.translate(<x>, <y>, <z>)
+        quadrotor.rotate(<rx>, <ry>, <rz>)
+
+        # define one or several communication interface, like 'socket'
+        quadrotor.add_interface(<interface>)
+
+        env = Environment('empty')
+
 
     .. note::
 
         The rotation of the rotors is fixed and only for show. Its speed
         can be adjusted in the Logic panel in Blender (shown with
         :kbd:`F4`) when the **cube** object are selected.
+
+    :noautoexample:
     """
 
     _name = 'Quadrotor'
@@ -20,7 +38,7 @@ class Quadrotor(morse.core.robot.Robot):
     def __init__(self, obj, parent=None):
         # Call the constructor of the parent class
         logger.info('%s initialization' % obj.name)
-        super(self.__class__, self).__init__(obj, parent)
+        morse.core.robot.Robot.__init__(self, obj, parent)
 
         logger.info('Component initialized')
 
