@@ -4,11 +4,13 @@ from morse.core import status, mathutils
 import morse.core.blenderapi
 from morse.sensors.camera import Camera
 from morse.sensors.video_camera import VideoCamera
-from morse.helpers.components import add_data
+from morse.helpers.components import add_data, add_property
 
 class AbstractDepthCamera(VideoCamera):
 
-    _short_desc = "A camera capturing 3D points cloud"
+    add_property('near_clipping', 1.0, 'cam_near')
+    add_property('far_clipping', 20.0, 'cam_far')
+    add_property('retrieve_depth', True, 'retrieve_depth')
 
     def __init__(self, obj, parent=None):
         """ Constructor method.
@@ -40,9 +42,9 @@ class AbstractDepthCamera(VideoCamera):
 
             self.capturing = True
 
-            if (self._n > 0):
+            if self._n > 0:
                 self._n -= 1
-                if (self._n == 0):
+                if self._n == 0:
                     self.completed(status.SUCCESS)
         else:
             self.capturing = False
@@ -66,9 +68,9 @@ class DepthCamera(AbstractDepthCamera):
     def initialize(self):
         from morse.sensors.zbufferto3d import ZBufferTo3D
         # Store the camera parameters necessary for image processing
-        self.converter = ZBufferTo3D(self.local_data['intrinsic_matrix'][0][0],\
-                                     self.local_data['intrinsic_matrix'][1][1],\
-                                     self.near_clipping, self.far_clipping, \
+        self.converter = ZBufferTo3D(self.local_data['intrinsic_matrix'][0][0],
+                                     self.local_data['intrinsic_matrix'][1][1],
+                                     self.near_clipping, self.far_clipping,
                                      self.image_width, self.image_height)
 
     def process_image(self, image):
@@ -101,7 +103,7 @@ class DepthVideoCamera(AbstractDepthCamera):
     def initialize(self):
         from morse.sensors.zbuffertodepth import ZBufferToDepth
         # Store the camera parameters necessary for image processing
-        self.converter = ZBufferToDepth(self.near_clipping, self.far_clipping, \
+        self.converter = ZBufferToDepth(self.near_clipping, self.far_clipping,
                                         self.image_width, self.image_height)
 
     def process_image(self, image):
@@ -127,3 +129,16 @@ class RawImage(AbstractDepthCamera):
         publish in C++, without having to re-serialize a Python object.
         """
         self.local_data['image'] = image
+
+
+class DepthCameraRotationZ(DepthCamera):
+    """Used for Velodyne sensor"""
+
+    add_property('rotation', 0.01745, 'rotation')
+
+    def default_action(self):
+        DepthCamera.default_action(self)
+        self.applyRotationZ(self.rotation)
+    def applyRotationZ(self, rotation):
+        # The second parameter specifies a "local" movement
+        self.bge_object.applyRotation([0, rotation, 0], True)
