@@ -159,7 +159,7 @@ class HumanPosture(morse.core.sensor.Sensor):
             The second parameter should be the name of the object's parent. """
         logger.info('%s initialization' % obj.name)
         # Call the constructor of the parent class
-        super(self.__class__, self).__init__(obj, parent)
+        morse.core.sensor.Sensor.__init__(self, obj, parent)
 
         logger.info('Component initialized, runs at %.2f Hz', self.frequency)
 
