@@ -43,7 +43,7 @@ class PTUPosture(morse.core.sensor.Sensor):
         """
         logger.info('%s initialization' % obj.name)
         # Call the constructor of the parent class
-        super(self.__class__,self).__init__(obj, parent)
+        morse.core.sensor.Sensor.__init__(self, obj, parent)
         
         ptu = self._get_ptu(self.bge_object)
         if not ptu:
