@@ -5,7 +5,6 @@ This script tests the KUKA LWR arm, both the data and service api
 
 import sys
 import math
-import time
 from morse.testing.testing import MorseTestCase
 from pymorse import Morse, MorseServiceFailed
 
@@ -17,22 +16,22 @@ except ImportError:
     pass
 
 JOINTS = ['kuka_1', 'kuka_2', 'kuka_3', 'kuka_4', 'kuka_5', 'kuka_6', 'kuka_7']
+
 class ArmatureTest(MorseTestCase):
     def setUpEnv(self):
         """ Defines the test scenario, using the Builder API.
         """
 
-        robot = ATRV()
+        robot = FakeRobot()
 
         arm = KukaLWR()
         robot.append(arm)
-        arm.translate(z=0.9)
         arm.add_stream('socket')
         arm.add_service('socket')
 
         pose = Pose()
         pose.add_stream('socket')
-        pose.translate(z=1.3)
+        pose.translate(z=1.3105)
         arm.append(pose)
 
         arm_pose = ArmaturePose()
@@ -46,13 +45,21 @@ class ArmatureTest(MorseTestCase):
         env = Environment('empty', fastmode = True)
         env.add_service('socket')
 
-    def checkstate(self, simu, angles, precision = 0.025):
+    def _check_state(self, simu, angles, precision = 0.050):
 
         pose = simu.robot.arm.arm_pose.get()
         target = dict(zip(JOINTS, angles))
 
         for j, v in pose.items():
-            self.assertAlmostEqual(v, target[j], delta=precision)
+            if j != 'timestamp':
+                self.assertAlmostEqual(v, target[j], delta=precision)
+
+    def _check_pose(self, simu, x, y, z, pitch, precision = 0.01):
+            self.assertAlmostEqual(simu.robot.arm.pose.get()['x'], x, delta = precision)
+            self.assertAlmostEqual(simu.robot.arm.pose.get()['y'], y, delta = precision)
+            self.assertAlmostEqual(simu.robot.arm.pose.get()['z'], z, delta = precision)
+            self.assertAlmostEqual(simu.robot.arm.pose.get()['pitch'], pitch, delta = precision)
+
 
 
     def test_object_attach(self):
@@ -62,21 +69,13 @@ class ArmatureTest(MorseTestCase):
 
         with Morse() as simu:
 
-            self.assertAlmostEqual(simu.robot.arm.pose.get()['z'], 2.3, delta = 0.01)
-            self.assertAlmostEqual(simu.robot.arm.pose.get()['x'], 0.0, delta = 0.01)
-            self.assertAlmostEqual(simu.robot.arm.pose.get()['y'], 0.0, delta = 0.01)
-            self.assertAlmostEqual(simu.robot.arm.pose.get()['pitch'], 0.0, delta = 0.01)
+            self._check_pose(simu, 0., 0., 1.3105, 0.)
             simu.robot.motion.translate(1.0)
-            time.sleep(0.1)
-            self.assertAlmostEqual(simu.robot.arm.pose.get()['z'], 2.3, delta = 0.01)
-            self.assertAlmostEqual(simu.robot.arm.pose.get()['x'], 1.0, delta = 0.01)
-            self.assertAlmostEqual(simu.robot.arm.pose.get()['y'], 0.0, delta = 0.01)
-            self.assertAlmostEqual(simu.robot.arm.pose.get()['pitch'], 0.0, delta = 0.01)
+            simu.sleep(0.1)
+            self._check_pose(simu, 1., 0., 1.3105, 0.)
             simu.robot.arm.set_rotation("kuka_2", math.radians(-90)).result()
-            time.sleep(0.1)
-            self.assertAlmostEqual(simu.robot.arm.pose.get()['z'], 1.31, delta = 0.01)
-            self.assertAlmostEqual(simu.robot.arm.pose.get()['x'], 1.99, delta = 0.01)
-            self.assertAlmostEqual(simu.robot.arm.pose.get()['pitch'], math.radians(90), delta = 0.01)
+            simu.sleep(0.1)
+            self._check_pose(simu, 2., 0., 0.3105, math.radians(90))
 
     def test_immediate_api(self):
         """ Tests the services that have an immediate result
@@ -89,11 +88,11 @@ class ArmatureTest(MorseTestCase):
 
         with Morse() as simu:
             simu.robot.arm.set_rotation("kuka_2", 1).result() # basic rotation
-            time.sleep(0.1)
+            simu.sleep(0.1)
             self.assertAlmostEqual(simu.robot.arm.arm_pose.get()["kuka_2"], 1.0, delta = precision)
 
             simu.robot.arm.set_rotation("kuka_2", 4000).result() # rotation clamping
-            time.sleep(0.1)
+            simu.sleep(0.1)
             self.assertAlmostEqual(simu.robot.arm.arm_pose.get()["kuka_2"], 2.09, delta = precision)
 
             res = simu.robot.arm.set_rotation('pipo',0) # inexistant joint
@@ -127,10 +126,10 @@ class ArmatureTest(MorseTestCase):
             simu.robot.arm.set_rotation("kuka_2", 0).result() # back to origin
             act = simu.robot.arm.rotate("kuka_2", 1, 0.5)
             self.assertFalse(act.done())
-            time.sleep(1)
+            simu.sleep(1)
             self.assertFalse(act.done())
             self.assertAlmostEqual(simu.robot.arm.arm_pose.get()["kuka_2"], 0.5, delta = precision)
-            time.sleep(1.1)
+            simu.sleep(1.1)
             self.assertTrue(act.done())
 
     def test_trajectory(self):
@@ -158,18 +157,18 @@ class ArmatureTest(MorseTestCase):
             self.assertIn('positions', str(act.exception()))
 
             act = simu.robot.arm.trajectory(traj1)
-            time.sleep(1)
-            self.checkstate(simu, [0.0, 1.0, 0,0,0,0,0])
-            time.sleep(3)
-            self.checkstate(simu, [0.0, 1.57, 0, -1.57,0,1.57,0])
-            time.sleep(2)
-            self.checkstate(simu, [0.0] * 7)
-            time.sleep(1)
-            self.checkstate(simu, [0.0] * 7)
+            simu.sleep(1)
+            self._check_state(simu, [0.0, 1.0, 0,0,0,0,0])
+            simu.sleep(3)
+            self._check_state(simu, [0.0, 1.57, 0, -1.57, 0, 1.57, 0])
+            simu.sleep(2)
+            self._check_state(simu, [0.0] * 7)
+            simu.sleep(1)
+            self._check_state(simu, [0.0] * 7)
 
             # check 'starttime' parameter
             act = simu.robot.arm.set_rotations([0.0] * 7)
-            traj2 = {'starttime': time.time() + 1,
+            traj2 = {'starttime': simu.time() + 1,
                     'points': [
                         {'positions': [0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0],
                         'time_from_start': 1.0}
@@ -177,24 +176,86 @@ class ArmatureTest(MorseTestCase):
                     }
 
             act = simu.robot.arm.trajectory(traj2)
-            time.sleep(0.5)
-            self.checkstate(simu, [0.0] * 7)
-            time.sleep(0.5)
-            time.sleep(1)
-            self.checkstate(simu, [0.0, 1.0, 0,0,0,0,0])
-            time.sleep(1)
-            self.checkstate(simu, [0.0, 1.0, 0,0,0,0,0])
+            simu.sleep(0.5)
+            self._check_state(simu, [0.0] * 7)
+            simu.sleep(0.5)
+            simu.sleep(1)
+            self._check_state(simu, [0.0, 1.0, 0,0,0,0,0])
+            simu.sleep(1)
+            self._check_state(simu, [0.0, 1.0, 0,0,0,0,0])
 
             # Check action cancellation
             act = simu.robot.arm.set_rotations([0.0] * 7)
 
-            traj2['starttime'] = time.time() + 1
+            traj2['starttime'] = simu.time() + 1
             act = simu.robot.arm.trajectory(traj2)
-            time.sleep(0.5)
+            simu.sleep(0.5)
             act.cancel()
-            time.sleep(1)
-            self.checkstate(simu, [0.0] * 7)
+            simu.sleep(1)
+            self._check_state(simu, [0.0] * 7)
 
+    def test_ik_immediate(self):
+
+        IK_TARGET = "ik_target.robot.arm.kuka_7"
+
+        with Morse() as simu:
+            self.assertEqual(simu.robot.arm.list_IK_targets(), [IK_TARGET])
+            self._check_pose(simu, 0., 0., 1.3105, 0.)
+
+            simu.robot.arm.place_IK_target(IK_TARGET, [0,0,2], None, False) # absolute location
+            simu.sleep(0.1)
+            self._check_pose(simu, 0., 0., 1.3105, 0.)
+
+            simu.robot.arm.place_IK_target(IK_TARGET, [1,0,0.3105], None, False)
+            simu.sleep(1) # with iterative IK solvers like iTaSC, the IK chain does not reach the end position immediately
+            self._check_pose(simu, 0.778, 0., 0.363, 0.02)
+
+            simu.robot.arm.place_IK_target(IK_TARGET, [1,0,0.3105], [math.pi/2, -math.pi/2, -math.pi], False) # arm should be horizontal
+            simu.sleep(1) # with iterative IK solvers like iTaSC, the IK chain does not reach the end position immediately
+            self._check_pose(simu, 1.0, 0., 0.3105, math.radians(90))
+
+            # back to original position
+            simu.robot.arm.place_IK_target(IK_TARGET, [0,0,2], [math.pi/2, 0., -math.pi], False) # absolute location
+            simu.sleep(1.)
+            self._check_pose(simu, 0., 0., 1.3105, 0.)
+
+            simu.robot.arm.place_IK_target(IK_TARGET, [-1, 0, -1.6895], None) # relative position
+            simu.sleep(1) # with iterative IK solvers like iTaSC, the IK chain does not reach the end position immediately
+            self._check_pose(simu, -0.778, 0., 0.363, -0.02)
+
+            simu.robot.arm.place_IK_target(IK_TARGET, [0.,0.,0.], [0., -math.pi/2, 0.]) # relative rotation
+            simu.sleep(1) # with iterative IK solvers like iTaSC, the IK chain does not reach the end position immediately
+            self._check_pose(simu, -1.0, 0., 0.3105, -math.radians(90))
+
+
+
+
+    def test_ik_motion(self):
+
+        IK_TARGET = "ik_target.robot.arm.kuka_7"
+
+        with Morse() as simu:
+            self.assertEqual(simu.robot.arm.list_IK_targets(), [IK_TARGET])
+            self._check_pose(simu, 0., 0., 1.3105, 0.)
+
+            simu.robot.arm.move_IK_target(IK_TARGET, [0,0,2], None, False).result() # absolute location
+            self._check_pose(simu, 0., 0., 1.3105, 0.)
+
+            simu.robot.arm.move_IK_target(IK_TARGET, [1,0,0.3105], None, False).result()
+            self._check_pose(simu, 0.778, 0., 0.363, 0.02)
+
+            simu.robot.arm.move_IK_target(IK_TARGET, [1,0,0.3105], [math.pi/2, -math.pi/2, -math.pi], False).result() # arm should be horizontal
+            self._check_pose(simu, 1.0, 0., 0.3105, math.radians(90))
+
+            # back to original position
+            simu.robot.arm.move_IK_target(IK_TARGET, [0,0,2], [math.pi/2, 0., -math.pi], False).result() # absolute location
+            self._check_pose(simu, 0., 0., 1.3105, 0.)
+
+            simu.robot.arm.move_IK_target(IK_TARGET, [-1, 0, -1.6895], None).result() # relative position
+            self._check_pose(simu, -0.778, 0., 0.363, -0.02)
+
+            simu.robot.arm.move_IK_target(IK_TARGET, [0.,0.,0.], [0., -math.pi/2, 0.]).result() # relative rotation
+            self._check_pose(simu, -1.0, 0., 0.3105, -math.radians(90))
 
 ########################## Run these tests ##########################
 if __name__ == "__main__":
