@@ -14,7 +14,7 @@ except ImportError:
     pass
 
 import sys
-import time
+import base64
 from pymorse import Morse
 
 class LightTest(MorseTestCase):
@@ -47,7 +47,7 @@ class LightTest(MorseTestCase):
 
             light_stream.publish({"emit": False})
 
-            time.sleep(1.0)
+            morse.sleep(1.0)
 
             # Light is shutdown. There is no light source on the scene,
             # so camera can't distinguish color
@@ -55,10 +55,10 @@ class LightTest(MorseTestCase):
 
             # search the green block in the image
             cam = cam_stream.get()
-            for i in range(320*240):
-                o = cam['image'][i]
+            img = base64.b64decode( cam['image'] )
+            for i in range(0, 320*240*4, 4):
                 # Value computed with gimp help ...
-                if (o['r'] < 5 and o['g'] > 110 and o['b'] < 5):
+                if (img[i] < 5 and img[i+1] > 110 and img[i+2] < 5):
                     res.append(i)
 
             self.assertEqual(len(res), 0)
@@ -66,13 +66,13 @@ class LightTest(MorseTestCase):
             # Now, illuminate the scene
             light_stream.publish({"emit": True})
 
-            time.sleep(2.0)
+            morse.sleep(2.0)
             cam = cam_stream.get()
+            img = base64.b64decode( cam['image'] )
             # search the green block in the image
-            for i in range(320*240):
-                o = cam['image'][i]
+            for i in range(0, 320*240*4, 4):
                 # Value computed with gimp help ...
-                if (o['r'] < 5 and o['g'] > 110 and o['b'] < 5):
+                if (img[i] < 5 and img[i+1] > 110 and img[i+2] < 5):
                     res.append(i)
 
             self.assertTrue(len(res) > 10000)
