@@ -4,7 +4,6 @@ This script tests the Segway RMP400 robot with differential drive actuator
 """
 
 import sys
-from time import sleep
 from morse.testing.testing import MorseTestCase
 from pymorse import Morse
 
@@ -15,34 +14,34 @@ try:
 except ImportError:
     pass
 
-def gradual_speed(s, v, w, t):
+def gradual_speed(s, morse, v, w, t):
     """ Start and finish applying only half of the desired speed """
     tic = t/20.0
     s.publish({'v' : v/4, 'w' : w/4})
-    sleep(tic*2)
+    morse.sleep(tic*2)
     s.publish({'v' : v/2, 'w' : w/2})
-    sleep(tic*1)
+    morse.sleep(tic*1)
     s.publish({'v' : v, 'w' : w})
-    sleep(tic*18)
+    morse.sleep(tic*18)
     s.publish({'v' : v/2, 'w' : w/2})
-    sleep(tic*2)
+    morse.sleep(tic*2)
     s.publish({'v' : v/4, 'w' : w/4})
-    sleep(tic*2)
+    morse.sleep(tic*2)
     s.publish({'v' : 0.0, 'w' : 0.0})
 
 
-def send_speed(s, v, w, t):
+def send_speed(s, morse, v, w, t):
     #s.publish({'v' : v, 'w' : w})
-    #sleep(t)
+    #morse.sleep(t)
     #s.publish({'v' : 0.0, 'w' : 0.0})
-    gradual_speed(s, v, w, t)
-    sleep(1)
+    gradual_speed(s, morse, v, w, t)
+    morse.sleep(1)
 
-def send_service_speed(s, v, w, t):
+def send_service_speed(s, morse, v, w, t):
     s.set_speed(v, w)
-    sleep(t)
+    morse.sleep(t)
     s.stop()
-    sleep(1)
+    morse.sleep(1)
 
 class Pioneer3DXTest(MorseTestCase):
     def setUpEnv(self):
@@ -70,23 +69,24 @@ class Pioneer3DXTest(MorseTestCase):
             pose_stream = morse.robot.pose
             pose = pose_stream.get()
             for key, coord in pose.items():
-                self.assertAlmostEqual(coord, 0.0, delta=0.03)
+                if key != 'timestamp':
+                    self.assertAlmostEqual(coord, 0.0, delta=0.05)
 
-            sleep(1)
+            morse.sleep(1)
 
             # Check that it does not dance :)
             pose = pose_stream.get()
             for key, coord in pose.items():
-                self.assertAlmostEqual(coord, 0.0, delta=0.03)
+                if key != 'timestamp':
+                    self.assertAlmostEqual(coord, 0.0, delta=0.05)
 
             v_w = morse.robot.motion
 
-            send_speed(v_w, 1.0, 0.0, 2.0)
+            send_speed(v_w, morse, 1.0, 0.0, 2.0)
 
             precision = 0.30
 
             pose = pose_stream.get()
-            print(pose)
             self.assertAlmostEqual(pose['x'], 2.0, delta=precision)
             self.assertAlmostEqual(pose['y'], 0.0, delta=precision)
             self.assertAlmostEqual(pose['z'], 0.0, delta=precision)
@@ -94,16 +94,16 @@ class Pioneer3DXTest(MorseTestCase):
             self.assertAlmostEqual(pose['pitch'], 0.0, delta=precision)
             self.assertAlmostEqual(pose['roll'], 0.0, delta=precision)
 
-            send_speed(v_w, -1.0, 0.0, 2.0)
+            send_speed(v_w, morse, -1.0, 0.0, 2.0)
 
             pose = pose_stream.get()
             for key, coord in pose.items():
-                self.assertAlmostEqual(coord, 0.0, delta=precision)
+                if key != 'timestamp':
+                    self.assertAlmostEqual(coord, 0.0, delta=precision)
 
-            send_speed(v_w, 1.0, -math.pi/4.0, 2.0)
+            send_speed(v_w, morse, 1.0, -math.pi/4.0, 2.0)
 
             pose = pose_stream.get()
-            print(pose)
             # for non-null w, we have r = v /  w
             self.assertAlmostEqual(pose['x'], 4.0/ math.pi , delta=precision)
             self.assertAlmostEqual(pose['y'], -4.0/ math.pi , delta=precision)
@@ -112,6 +112,10 @@ class Pioneer3DXTest(MorseTestCase):
             self.assertAlmostEqual(pose['pitch'], 0.0, delta=precision)
             self.assertAlmostEqual(pose['roll'], 0.0, delta=precision)
 
+
+    # Desactive this test for now. With no control on acceleration, the
+    # result of service calling is often relatively too fuzzy to make a
+    # repeatable test
     def _test_vw_service_controller(self):
         with Morse() as morse:
         
@@ -119,12 +123,13 @@ class Pioneer3DXTest(MorseTestCase):
             pose_stream = morse.robot.pose
             pose = pose_stream.get()
             for key, coord in pose.items():
-                self.assertAlmostEqual(coord, 0.0, delta=0.02)
+                if key != 'timestamp':
+                    self.assertAlmostEqual(coord, 0.0, delta=0.05)
 
             v_w = morse.robot.motion
 
-            precision = 0.30
-            send_service_speed(v_w, 1.0, 0.0, 2.0)
+            precision = 0.40
+            send_service_speed(v_w, morse, 1.0, 0.0, 2.0)
 
             pose = pose_stream.get()
             self.assertAlmostEqual(pose['x'], 2.0, delta=precision)
@@ -134,13 +139,14 @@ class Pioneer3DXTest(MorseTestCase):
             self.assertAlmostEqual(pose['pitch'], 0.0, delta=precision)
             self.assertAlmostEqual(pose['roll'], 0.0, delta=precision)
 
-            send_service_speed(v_w, -1.0, 0.0, 2.0)
+            send_service_speed(v_w, morse, -1.0, 0.0, 2.0)
 
             pose = pose_stream.get()
             for key, coord in pose.items():
-                self.assertAlmostEqual(coord, 0.0, delta=precision)
+                if key != 'timestamp':
+                    self.assertAlmostEqual(coord, 0.0, delta=precision)
 
-            send_service_speed(v_w, 1.0, -math.pi/4.0, 2.0)
+            send_service_speed(v_w, morse, 1.0, -math.pi/4.0, 2.0)
 
             pose = pose_stream.get()
             # for non-null w, we have r = v /  w
