@@ -33,7 +33,7 @@ class PR2TorsoTest(MorseTestCase):
         pr2.add_stream('socket')
 
         env = Environment('empty', fastmode=True)
-        env.aim_camera([1.0470, 0, 0.7854])
+        env.set_camera_rotation([1.0470, 0, 0.7854])
 
     def test_head_pan(self):
         
