@@ -14,7 +14,6 @@ except ImportError:
     pass
 
 import sys
-import time
 
 from pymorse import Morse
 
@@ -30,7 +29,7 @@ class PR2TorsoTest(MorseTestCase):
         pr2.add_interface('socket')
 
         env = Environment('empty', fastmode=True)
-        env.aim_camera([1.0470, 0, 0.7854])
+        env.set_camera_rotation([1.0470, 0, 0.7854])
 
     def test_torso_translate(self):
         
@@ -44,17 +43,17 @@ class PR2TorsoTest(MorseTestCase):
             logger.info("Moving up torso to 0.2m...")
             action = simu.pr2.torso.translate(joint, 0.2, 0.1) # speed = 0.1 m/s
 
-            time.sleep(1)
+            simu.sleep(1)
             logger.info("Should be now at 0.1m...")
             self.assertAlmostEquals(getjoint(simu, joint), 0.1, 1)
 
-            time.sleep(1)
+            simu.sleep(1)
             logger.info("Should be now at 0.2m...")
             self.assertAlmostEquals(getjoint(simu, joint), 0.2, 1)
 
             # Check we do not move anymore
             logger.info("Should not move anymore...")
-            time.sleep(0.5)
+            simu.sleep(0.5)
             self.assertFalse(action.running())
             self.assertAlmostEquals(getjoint(simu, joint), 0.2, 1)
 
@@ -62,14 +61,14 @@ class PR2TorsoTest(MorseTestCase):
             #TODO: currently no way to stop the action when blocking on a joint limit since we can not retreive them from Python (blender 2.64)
             #logger.info("Let's go as high as possible to check my limits...")
             #action = simu.pr2.torso.translate(joint, [0, 1, 0], 0.2) # speed = 0.2 m/s
-            #time.sleep(2)
+            #simu.sleep(2)
             #self.assertFalse(action.running())
             #self.assertAlmostEquals(getjoint(simu, joint), 0.3, 1)
 
             # Go back to initial position
             logger.info("Let's go back down...")
             action = simu.pr2.torso.translate(joint, 0, 0.2) # speed = 0.2 m/s
-            time.sleep(1.6)
+            simu.sleep(1.6)
             self.assertFalse(action.running())
             self.assertAlmostEquals(getjoint(simu, joint), 0.0, 1)
 
@@ -77,16 +76,16 @@ class PR2TorsoTest(MorseTestCase):
             logger.info("Moving up torso to 0.2m...")
             simu.pr2.torso.set_translation(joint, 0.2)
             logger.info("Should be now at 0.2m...")
-            time.sleep(.1)
+            simu.sleep(.1)
             self.assertAlmostEquals(getjoint(simu, joint), 0.2, 3)
 
             # Test limits
             logger.info("Let's go as high as possible to check my limits...")
             simu.pr2.torso.set_translation(joint, 1)
-            time.sleep(.1)
+            simu.sleep(.1)
             self.assertAlmostEquals(getjoint(simu, joint), 0.31, 3)
             simu.pr2.torso.set_translation(joint, -1)
-            time.sleep(.1)
+            simu.sleep(.1)
             self.assertAlmostEquals(getjoint(simu, joint), 0.0, 3)
 
 
